/*******************************************************************\

Module: Pointer Dereferencing

Author: Daniel Kroening, kroening@kroening.com

\*******************************************************************/

#ifndef CPROVER_POINTER_ANALYSIS_POINTER_OFFSET_SUM_H
#define CPROVER_POINTER_ANALYSIS_POINTER_OFFSET_SUM_H

#include <util/expr.h>

exprt pointer_offset_sum(const exprt &a, const exprt &b);

#endif
